@@ -19,6 +19,9 @@ from .core import *
 # from . import viz
 # from .viz import *
 
+from . import statistics
+from .statistics import *
+
 from .io import *
 from .misc import *
 from .version import __version__
@@ -37,6 +40,7 @@ __all__.extend(analysis.__all__)
 __all__.extend(core.__all__)
 # __all__.extend(external.__all__)
 # __all__.extend(geometry.__all__)
+__all__.extend(statistics.__all__)
 # __all__.extend(viz.__all__)
 
 # Add include path
