@@ -1,10 +1,14 @@
 
+from .distance import *
+
+from .protein import *
 from . import protein
 
 from .rmsd import *
-from .protein import *
+
 
 __all__ = [
+    'distance',
     'rmsd',
 ]
 
